#!/bin/bash
# ubuild.sh originally by Iguleder
# hacked to DEATH by 01micko
# Firmware download option big or cut from ibiblio.
# unattended wrapper by stemsee > nubuild.sh
# deblob-kernel-code libre-linux from Iguleder
# see /usr/share/doc/legal NO WARRANTY, NO responsibility accepted
# kernel Compile and build
bldkern (){
if [[ -d ./aufs* ]]; then
	echo "This is not a clean kit."
	sleep 8
fi
if [ ! -f vanilla/linux-$kernel_version.tar.xz ]; then

# download the kernel
echo ${kernel_version##*-} | grep -q "rc"
[ "$?" -eq 0 ] && testing=testing || testing=
	if [[ ! -f vanilla/linux-$kernel_version.tar.xz ]]; then
	echo "Downloading the kernel sources"
	wget --no-check-certificate -P vanilla $kernel_mirror/linux-$kernel_version.tar.xz 
		if [[ $? -ne 0 ]]; then
			echo "Error: failed to download the kernel sources."
			exit 1
		fi
	fi
elif [ -f vanilla/linux-$kernel_version.tar.xz ]; then
echo "Kernel Sources already there!"
fi
# download Linux-libre scripts
if [ $LIBRE -eq 1 ]; then
	minor_version=${kernel_version##*.}
	for i in deblob-$kernel_major_version deblob-check; do
		if [ ! -f vanilla/$i ]; then
			wget --no-check-certificate -O vanilla/$i http://linux-libre.fsfla.org/pub/linux-libre/releases/LATEST-"$ver".N/$i
			if [ $? -ne 0 ]; then
				echo "Error: failed to download $i."
				exit 1
			fi
		fi
	done
fi
kernel_branch=`echo $latest | cut -f2 -d'.'`
# download Aufs
if [ ! -f vanilla/aufs$ver-$kernel_branch.tar.bz2 ]; then
downaufs (){
	echo "Downloading the Aufs sources" 
case $ver in
	[4-9]) git clone https://github.com/sfjro/aufs-standalone.git aufs$ver.$aufsbranch
		rename master aufs"$ver"."$aufsbranch" master;;
	[1-3]) git clone https://git.code.sf.net/p/aufs/aufs$ver-standalone aufs-aufs$ver-standalone
		rename master aufs"$ver"."$aufsbranch" master;;
	esac
}; downaufs
		cd aufs$ver.$aufsbranch
		git checkout origin/aufs$ver.$aufsbranch
		if [ $? -ne 0 ]; then
				echo "Error: failed to download the Aufs sources."
				exit 0
		fi
		rm -rf .git
		cd ..
		echo "Creating the Aufs sources tarball" 
		tar -cf aufs${ver}.${aufsbranch} | bzip2 -9 > vanilla/aufs${ver}.${aufsbranch}.tar.bz2
	echo "Extracting the Aufs sources" 
	tar -xf vanilla/aufs${ver}.${aufsbranch}.tar.bz2 >> build.log 2>&1
	if [ $? -ne 0 ]; then
		echo "Error: failed to extract the Aufs sources." 
		exit 1
	fi
fi
# patch Aufs
if [ -f aufs-allow-sfs.patch ];then #removed for K3.9 experiment
	echo "Patching the Aufs sources"
	patch -d aufs${ver}.${aufsbranch} -p1 < aufs-allow-sfs.patch >> build.log 2>&1
	if [ $? -ne 0 ]; then
		echo "Error: failed to patch the Aufs sources." 
		exit 1
	fi
	cp aufs-allow-sfs.patch patches
fi
if [ -f aufs-kconfig.patch ]; then #special for K3.9
	echo  "Patching the Aufs sources" 
	patch -d aufs${ver}.${aufsbranch} -p1 < aufs-kconfig.patch >> build.log 2>&1
	if [ $? -ne 0 ]; then
		echo  "Error: failed to patch the Aufs sources for kconfig." 
		exit 1
	fi
	cp aufs-kconfig.patch patches
fi
# extract the kernel
echo  "Extracting the kernel sources" 
tar -xf vanilla/linux-${latest}.tar.* >> build.log 2>&1
if [ $? -ne 0 ]; then
	echo  "Error: failed to extract the kernel sources." 
	exit 1
fi
cd linux-${kernel_version}
echo  "Adding Aufs to the kernel sources" 
for i in kbuild base standalone mmap; do
	patch -N -p1 < ../aufs${ver}.${aufsbranch}/aufs${ver}-$i.patch >> ../build.log 2>&1
	if [ $? -ne 0 ]; then
		echo  "Error: failed to add Aufs to the kernel sources.
		WARNING: failed to add some Aufs patches to the kernel sources.
		Check it manually and either CRTL+C to bail or hit return to go on" 
		sleep 8
	fi
done
#aufspatch
cp -r ../aufs${ver}.${aufsbranch}/{fs,Documentation} .
cp ../aufs${ver}.${aufsbranch}/include/linux/aufs_type.h include/uapi/linux 2>/dev/null
cp ../aufs${ver}.${aufsbranch}/include/uapi/linux/aufs_type.h include/uapi/linux 2>/dev/null
[ -d ../aufs${ver}.${aufsbranch}/include/uapi ] && cp -r ../aufs${ver}.${aufsbranch}/include/uapi/linux/aufs_type.h include/uapi/linux
# deblob the kernel
if [ $LIBRE -eq 1 ]; then
	cd ..
	cp -r linux-${kernel_version} linux-$kernel_version-orig
	cd linux-${kernel_version}
	sh ../vanilla/deblob-${kernel_major_version} 2>&1 | tee -a ../build.log
	cd ..
	diff -rupN linux-${kernel_version}-orig linux-${kernel_version} > patches/deblob.patch
	rm -rf linux-${kernel_version}-orig
	cd linux-${kernel_version}
fi
echo  "Resetting the minor version number" 
cp -f Makefile Makefile-orig
sed -i "s/^EXTRAVERSION =/EXTRAVERSION = $nwsfix/" Makefile
diff -up Makefile-orig Makefile > ../patches/extra-version.patch
rm Makefile-orig
	 cp kernel/printk/printk.c kernel/printk/printk.c.orig
	 sed -i s/'#define MAX_CMDLINECONSOLES 8'/'#define MAX_CMDLINECONSOLES 5'/ kernel/printk/printk.c
	 diff -up kernel/printk/printk.c.orig kernel/printk/printk.c > ../patches/less-consoles.patch
	 echo "Reducing the verbosity level"
	 cp -f include/linux/printk.h include/linux/printk.h.orig
	 sed -i s/'#define CONSOLE_LOGLEVEL_DEFAULT 7 \/\* anything MORE serious than KERN_DEBUG \*\/'/'#define CONSOLE_LOGLEVEL_DEFAULT 3 \/\* anything MORE serious than KERN_ERR \*\/'/ include/linux/printk.h
	 diff -up include/linux/printk.h.orig include/linux/printk.h > ../patches/lower-verbosity.patch
#patches
for patch in ../patches/patch* ../patches/aufs* ../patches/*
do
	echo  "Applying $patch" 
	patch -p1 < $patch >> ../build.log 2>&1
	if [ "$?" -ne 0 ]; then
		echo  "Error: failed to apply $patch on the kernel sources." 
	fi
done
#cleaningsrc
echo "Cleaning the kernel sources" 

if [ -z "$DEB" ]; then
	make clean
else
	make-kpkg clean
fi
find . -name '*.orig' -delete
find . -name '*.rej' -delete
find . -name '*~' -delete 
[ ../DOTconfig ] && rm -f ../DOTconfig
case $car in
1) cp -af ../configs_extra_user/DOTconfig-64 ../DOTconfig;;
2) cp -af ../configs_extra_user/DOTconfig-pae ../DOTconfig;;
3) cp -af ../configs_extra_user/DOTconfig-nopae ../DOTconfig;;
esac
#Pause to configure
#configure
clear
kernelconfig=$(whiptail --inputbox "For unattended config of new kernels do nothing here!
For old kernel versions or other customisations enter 2 ... 

1. make localyesconfig
2. make menuconfig 
3. make oldconfig" 20 60 3>&1 1>&2 2>&3)

#read kernelconfig
if [ ! -z "$kernelconfig" ]; then
	echo "You entered $kernelconfig" 
fi
if [ "$arc" = 888 ]; then
	kernelconfig=2
fi
cp -f ../DOTconfig .config.old
cp -f ../DOTconfig .config
case $kernelconfig in
1) make olddefconfig;;
2) echo "Configure $arch kernel"
sleep 2
make menuconfig
if [ "$arc" -eq 888 ]; then
mv -f .config ../configs_extra_user/DOTconfig-64
mv -f ../configs_extra_user/DOTconfig-pae .config
echo "Configure pae kernel."
sleep 2
make menuconfig
mv -f .config ../configs_extra_user/DOTconfig-pae
sed -i "s/$nwsfix-64/$nwsfix-pae/" ../configs_extra_user/DOTconfig-pae
mv -f ../configs_extra_user/DOTconfig-nopae .config
echo "Configure nopae kernel."
sleep 2
make menuconfig
mv -f .config ../configs_extra_user/DOTconfig-nopae
sed -i "s/$nwsfix-64/$nwsfix-nopae/" ../configs_extra_user/DOTconfig-nopae
cp -f ../configs_extra_user/DOTconfig-64 .config
echo "Finished and continuing to compile 64 bit kernel."
fi
;;
3) make oldconfig;;
esac
echo
echo "Ok, kernel is configured. CTRL+C to quit" 
cp -f .config ../configs_extra/DOTconfig-$latest$kern$today
sleep 2
[ ! -d ../dist/packages ] && mkdir -p ../dist/packages
#krnheads
if [ ! -d ../kernel_headers-$latest$nwsfix$arch ]; then
	echo "Creating the kernel headers package"
	make headers_check >> ../build.log 2>&1
	make INSTALL_HDR_PATH=kernel_headers-$latest$nwsfix$arch/usr headers_install >> ../build.log 2>&1
	find kernel_headers-$latest$nwsfix$arch/usr/include \( -name .install -o -name ..install.cmd \) -delete
	mv kernel_headers-$latest$nwsfix$arch ../
fi
cd ..
# build aufs-utils userspace modules
echo "Now to build the aufs-utils for userspace" 
if [[ ! -f vanilla/aufs-util${today}.tar.bz2 ]]; then
	git clone "$aufs_utils_git" aufs-util
	[ $? -ne 0 ] && echo "Failed to get aufs-util from git, do it manually :)"
	cd aufs-util
	git branch -a | grep "aufs${ver}" | grep -v 'rcN' | cut -f2 -d'.' > /tmp/aufs-util-version #we go for stable only
	nowt=$(cat /tmp/aufs-util-version)
	if [[ -z "$nowt" ]]; then
		echo "$((kernel_branch - 1))" > /tmp/aufs-util-version
	fi
	while read line
	  do 
	    if [[ "$line" -le "$kernel_branch" ]]; then 
			branch=$line
	    fi
	  done < /tmp/aufs-util-version
	#branch=$(cat /tmp/aufs-util-version)
	git checkout origin/aufs${ver}.$branch >> ../build.log 2>&1
	[ $? -ne 0 ] && echo "Failed to get aufs-util from git, do it manually. Kernel is compiled OK :)"
	# patch Makefile for static build
	echo "Patching aufs-util sources"
	cp -f Makefile Makefile.orig
	sed -i 's/-static //' Makefile
	rm ../patches/aufs-util-dynamic.patch
	diff -ru Makefile.orig Makefile > ../patches/aufs-util-dynamic.patch
	rm Makefile.orig
	patch -p1 < ../patches/aufs-util-dynamic.patch >> ../build.log 2>&1
	[ "$?" -ne 0 ] && echo "Failed to patch the aufs-util sources."
else
	echo "Extracting the Aufs-util sources" 
	tar -xf vanilla/aufs-util$today.tar.bz2 >> ../build.log 2>&1
		if [ $? -ne 0 ]; then
			echo "Error: failed to extract the aufs-util sources."
			exit 1
		fi	
	cd aufs-util	
fi
# see if fhsm is enabled in kernel config
grep -q 'CONFIG_AUFS_FHSM=y' ../linux-$latest/.config
[ "$?" -eq 0 ] && export MAKE=make || export MAKE="make BuildFHSM=no"
LinuxSrc="$CWD/kernel_headers-$latest$nwsfix$arch"
export CPPFLAGS="-I $LinuxSrc/usr/include"
$MAKE >> ../build.log 2>&1
[ $? -ne 0 ] && echo "Failed to compile aufs-util, do it manually. Kernel is compiled OK :)"
make DESTDIR=$CWD/dist/packages/kernel-modules-$latest$nwsfix$arch install >> ../build.log 2>&1 #needs absolute path
make clean >> ../build.log 2>&1
tar -cf ../aufs-util ../vanilla/aufs-util$today.tar.bz2
if [[ "$arch" = "x86_64" ]];then
	[[ -d ../dist/packages/kernel-modules-$latest$nwsfix$arch/usr/lib ]] && mv ../dist/packages/kernel-modules/usr/lib ../dist/packages/kernel-modules/usr/lib64
fi
echo "aufs-util is in dist"
cd ../
#krncompile
if [[ -d linux-$latest ]]; then
	cd linux-$latest
else
	export latest="${latest}.0"
	cd linux-$latest
fi
echo "Compiling the kernel"
	if [[ -z "$DEB" ]]; then
		make -j$(nproc)
	elif [[ ! -z "$DEB" ]]; then
		mkdir ./debian
		fakeroot make-kpkg -j$(nproc) --initrd --revision="$latest.$nwsfix" kernel_image kernel_headers
		make clean
		cd ..
		mksquashfs linux-"$latest" kernel_sources-"$latest".sfs -comp xz
	fi
if [[ -z "$DEB" ]]; then
	if [[ ! -f arch/x86/boot/bzImage || ! -f System.map ]]; then
		echo "Error: failed to compile the kernel sources."
		exit 1
	fi



	confname="DOTconfig-$latest-$timestamp"
	confdir="configs_extra"

cp .config ../"$confdir"/"$confname"
#krncompile
echo "Creating the kernel package"
make INSTALL_MOD_PATH=../dist/packages/kernel-modules-$latest$nwsfix$arch"$libpath" modules_install >> ../build.log 2>&1
mkdir -p ../dist/packages/kernel-modules-$latest$nwsfix$arch/boot
mkdir -p ../dist/packages/kernel-modules-$latest$nwsfix$arch/etc/modules
cp .config ../dist/packages/kernel-modules-$latest$nwsfix$arch/etc/modules/DOTconfig-$latest$nwsfix$arch
cp arch/x86/boot/bzImage ../dist/packages/kernel-modules-$latest$nwsfix$arch/boot/vmlinuz-$latest$nwsfix$arch
cp System.map ../dist/packages/kernel-modules-$latest$nwsfix$arch/boot/
cp ../dist/packages/kernel-modules-$latest$nwsfix$arch/lib/modules/${latest}$nwsfix/{modules.builtin,modules.order} ../dist/packages/kernel-modules-$latest$nwsfix$arch/etc/modules/
	mv ../dist/packages/kernel-modules-$latest$nwsfix$arch/boot/vmlinuz-$latest$nwsfix$arch ../dist/packages/vmlinuz-$latest$nwsfix"$arch"
	[[ -f ../dist/packages/kernel-modules-$latest$nwsfix$arch/boot/bzImage ]] && rm -f ../dist/packages/kernel-modules-$latest$nwsfix$arch/boot/bzImage
echo "Cleaning the kernel sources"
make clean >> ../build.log 2>&1
make prepare >> ../build.log 2>&1
cd $CWD
	if [[ "$firmdl" != s && "$firmdl" != b ]]; then
		cp -a /lib/firmware dist/packages/kernel-modules-$latest$nwsfix$arch"$libpath"/lib/
	fi
	[[ "$firmdl" = s ]] && tar -xjf vanilla/firmware-140621-small.tar.bz2 -C dist/packages/kernel-modules-$latest$nwsfix$arch"$libpath"/lib/
	[[ "$firmdl" = b ]] && tar -xjf vanilla/firmware-140621-big.tar.bz2 -C dist/packages/kernel-modules-$latest$nwsfix$arch"$libpath"/lib/
	#rm -f ../dist/packages/kernel-modules-$latest$nwsfix$arch/lib/modules/${latest}$nwsfix/build
	#rm -f ../dist/packages/kernel-modules-$latest$nwsfix$arch/lib/modules/${latest}$nwsfix/source
	mksquashfs dist/packages/kernel-modules-$latest$nwsfix$arch dist/packages/kernel-modules.sfs-"$latest""$nwsfix""$arch" $COMP
	rm -rf dist/packages/kernel-modules-$latest$nwsfix$arch
	echo "Packaging huge-$latest$nwsfix$arch kernel"
	cd dist/packages/
	tar -cjvf huge-$latest${nwsfix}"$arch".tar.bz2 vmlinuz-$latest$nwsfix$arch kernel-modules.sfs-$latest$nwsfix$arch
	md5sum huge-$latest${nwsfix}"$arch".tar.bz2 > huge-$latest${nwsfix}"$arch".tar.bz2.md5.txt
	echo "Huge kernel $latest$nwsfix$arch/ is ready in dist"
fi
cd $CWD
clear
echo " Done!"
[ -f /usr/share/sounds/2barks.au ] && aplay /usr/share/sounds/2barks.au
}
mkkernsrc () {
	echo "Creating the kernel Sources SFS module"
	echo "Creating a kernel sources SFS" > build.log 2>&1
	mkdir -p kernel_sources-$latest$nwsfix$arch/{$libpath/lib/modules/$latest$nwsfix,usr/src} > build.log 2>&1
	mv linux-${latest}${nwsfix} kernel_sources-$latest$nwsfix$arch/usr/src/linux > build.log 2>&1
	ln -s kernel_sources-$latest$nwsfix$arch/usr/src/linux kernel_sources-$latest$nwsfix$arch$libpath/modules/${latest}${nwsfix}/source > build.log 2>&1
	ln -s kernel_sources-$latest$nwsfix$arch/usr/src/linux kernel_sources-$latest$nwsfix$arch$libpath/modules/${latest}${nwsfix}/build > build.log 2>&1
	if [ [ ! -f kernel_sources-$latest$nwsfix$arch/usr/src/linux/include/linux/version.h ]] ;  then
		ln -s /usr/src/linux/include/generated/uapi/linux/version.h kernel_sources-$latest$nwsfix$arch/usr/src/linux/include/linux/version.h
	fi
	rm -rf kernel_sources-$latest$nwsfix$arch/usr/src/linux/.git*
	cd $CWD
	mv -f kernel_headers-$latest$nwsfix$arch/usr/include kernel_sources-$latest$nwsfix$arch/usr/
	mksquashfs kernel_sources-"$latest$nwsfix$arch" dist/packages/kernel_sources-"$latest$nwsfix$arch".sfs $COMP -noappend > build.log 2>&1
	echo "kernel sources sfs module complete"
	[[ ! -d debs ]] && mkdir debs
	[[ *.deb ]] && mv *.deb debs/
	[[ *.sfs ]] && mv *.sfs debs/
}
if [ "$1" = makesources ]; then
	[[ /tmp/sukkvars ]] && . /tmp/sukkvars
	mkkernsrc
	exit 0
fi
if [ "$1" = reset ]; then
	rm -f vanilla/linux-*
	rm -f vanilla/aufs*
	rm -rf dist/kernel_headers*
	rm -f /tmp/firmware-*
	rm -f /tmp/megatools*
	rm -f vanilla/deblob*
	rm /tmp/sukkvars
fi
export CWD=`pwd`
export Version="3.0"
export timelimit=16
export old=6.10
export aufs_utils_git="http://git.code.sf.net/p/aufs/aufs-util"
export COMP="-comp xz"
export today="-`date +%m%y`"
export tmstamp=`date | cut -f2,3 -d ' ' | tr ' ' '-' | cut -f1 -d ':'`
cd "$CWD"
dummy=$(whiptail --inputbox "Safety catch. Press Enter to Continue" 20 60 3>&1 1>&2 2>&3)
#read dummy
echo "Cleaning ... Please Wait" 
	echo -en "[1;35m""WARNING" #purple?
	echo -en "[0m" #reset
	rm -rf ./{aufs*,linux*,kernel*,build.log*}
	rm -f build.log.bz2
	rm -f /tmp/aufs-util-version
	rm -f /tmp/sukkvars
	latest=$(whiptail --inputbox "Cleaning complete.
Please enter the kernel version you would like this script to compile.
Current version setting is '$old' 
e.g.    6.10

" 20 60 3>&1 1>&2 2>&3)
#read latest
if [ -z "$latest" ]; then
	export latest="$old"
fi
aufsbranch=$(whiptail --inputbox "Set aufs branch manually
e.g. 9
" 20 60 3>&1 1>&2 2>&3)
#read a 3>&1 1>&2 2>&3ufsbranch
[[ -z "$aufsbranch" ]] && aufsbranch="$kernel_branch"
export latest="$latest" 
export nafsv=`echo $latest | cut -f1,2 -d'.'`
export ver=`echo $latest | cut -f1 -d'.'`
export kernel_version=$latest
export kernel_major_version=$nafsv
export kernel_branch=`echo $latest | cut -f2 -d'.'`
export kernel_mirror="https://cdn.kernel.org/pub/linux/kernel/v$ver.x/"
export aufs_git=git://github.com/sfjro/aufs$ver-standalone.git
arc=$(whiptail --inputbox "Please load your devx	Or install development files.
Please enter number indicating which kernel to build

e.g.    1) 64bit
        2) 32bit-pae
        3) 32bit-nopae
" 20 60 3>&1 1>&2 2>&3)
#read arc DEB
[[ ! -z "$DEB" && ! -z "$arc"  ]] && export DEB
if [ -z "$arc" ]; then
	export arc="1"
fi

mkdir -p dist/previouspkgs-"$today" 
if [ -d dist/packages* ]; then
	mv -f dist/packages* dist/previouspkgs-"$today" 
fi

echo
nwsfix=$(whiptail --inputbox "You can change the custom name on the kernel. Better not use minus symbol -.
Presently it is '$olsfix'. For debian system use lowercase only." 20 60 3>&1 1>&2 2>&3)
#read nwsfix
if [ -z "$nwsfix" ]; then
	export nwsfix="$olsfix"
fi
echo "$nwsfix" 
export nwsfix="$nwsfix"
clear
echo  "Testing internet connection" 
function ETfn (){
ETphonehome=`curl --connect-timeout 10 http://icanhazip.com | grep -e [0-9]*.[0-9]*.[0-9]*.* -e *:*:*:*:*:*:*`
[[ -f devx/*devx*.s*fs ]] && losetup -f devx/*devx*.s*fs
if [[ -z "$ETphonehome" ]]; then
	echo "10 second delay, PLEASE connect to internet!"
else
	echo "Connected to internet with devx loaded!"
fi
	echo "Dependency check..."
if [ ! -z "$DEB" ]; then
	echo "For deb these packages must be installed:
	fakeroot build-essential kernel-package libssl-dev git ncurses-dev bc
	linux-libc-dev etc.
	Install will be attempted now if you press 'i'"
	read install
	if [[ "$install" = i ]]; then
		doit=`busybox which apt-get`
		if [[ ! -z "$doit" ]]; then
			sudo apt-get update
			sudo apt-get -y install fakeroot build-essential kernel-package linux-libc-dev git libncurses-dev libssl-dev bc -y
		else
			go=`busybox which slapt-get`
			if [[ ! -z "$go" ]]; then
				slapt-get -u
				slapt-get --install fakeroot bc
			fi
		fi
	fi
	if fakeroot --version &>/dev/null
		then echo -e "[1;32m""fakeroot is installed" #green 
	else echo -e "[1;31m""fakeroot might not be installed""[0m" #red
	fi
fi
if git --version &>/dev/null
	then echo -e "[1;32m""git is installed" #green 
else echo -e "[1;31m""git is not installed...LOAD devx.sfs!""[0m" && exit #red
fi
if gcc --version &>/dev/null
	then echo -e "[1;32m""gcc is installed" 
else
   echo -e "[1;31m""gcc is not installed...LOAD devx.sfs!""[0m" && exit
fi
MKSQ="$(busybox which mksquashfs)"
if [ "$MKSQ" ]
	then 
   echo -e "[1;32m""mksquashfs is installed"
else #yellow
   echo -e "[1;30m""mksquashfs is not installed but you can continue"
fi
}
ETfn
firmdl=$(whiptail --inputbix "To download firmware enter a or b or s,
all=144M | big=16.6M | small=9.7M
to NOT download press enter and firwmware will be copied from /lib/firmware" 20 60)
#read firmdl
case $firmdl in
	a) wget -t0 -c https://mirrors.edge.kernel.org/pub/linux/kernel/firmware/ -O /tmp/k.html
	lnum=`grep -n sha256 /tmp/k.html | cut -c1,2`
	lnum=$((lnum - 1))
fw=`echo $lnum | cut -f2 -d'>' | cut -f1 -d'<'`
wget -t0 -c https://mirrors.edge.kernel.org/pub/linux/kernel/firmware/$fw -P vanilla/
xz -d vanilla/$fw;;
	b) wget -t0 -c http://distro.ibiblio.org/puppylinux/firmware/firmware-140621-big.tar.bz2 -P vanilla/;;
	s) wget -t0 -c http://distro.ibiblio.org/puppylinux/firmware/firmware-140621-cut.tar.bz2 -P vanilla/;;
	*) ;;
esac
echo
LIBRE=$(whiptail --inputbox "This option removes non-free frimware from kernel.
Deblob kernel? 'y' or Enter for 'no'" 20 60 3>&1 1>&2 2>&3)
#read LIBRE
case $LIBRE in
	y) LIBRE=1;;
	n) LIBRE=0;;
	*) LIBRE=0;;
esac
usrmerge=$(whiptail --inputbox "UsrMerge 
modules in /lib or /usr/lib ?
A or B, Enter for non-usrmerge" 20 60 3>&1 1>&2 2>&3)
#read usrmerge
case $usrmerge in
A) export libpath="";;
B) export libpath='/usr';;
*) export libpath="";;
esac
# depcheck

echo -e "[0m" #reset to original
export xis=$arc
case $xis in
	1) arch="-x86_64"
	export arch
		kern="-64"
		export kern
		exname="-puppy"
		export olsfix=$exname$kern
		;;
	2) arch="-i686"
		export arch
		kern="-32-pae"
		export kern
		exname="-puppy"
		export olsfix=$exname$kern
		;;
	3) arch="-i486"
	export arch
		kern="-32-nopae"
		export kern
		exname="-puppy"
		export olsfix=$exname$kern
		;;
	888) echo;;
esac
case $arc in
	1|2|3) car=$arc
		bldkern
	if [[ -z "$DEB" ]]; then
		mkkernsrc
	fi
	rename packages packages$kern dist/packages
	;;
	
	12|21) car=1
	bldkern
	if [[ -z "$DEB" ]]; then 
		mkkernsrc
		rename packages packages$kern dist/packages
	fi
	car=2
	bldkern
	if [[ -z "$DEB" ]]; then 
		mkkernsrc
		rename packages packages$kern dist/packages
	fi;;
	
	13|31)  car=1
	bldkern
	if [[ -z "$DEB" ]]; then 
		mkkernsrc
		rename packages packages64 dist/packages
	fi
	car=3
	bldkern
	if [[ -z "$DEB" ]]; then
		mkkernsrc
		rename packages packages32-nopae dist/packages
	fi;;
	
	23|32) car=2
	bldkern
	if [[ -z "$DEB" ]]; then
		mkkernsrc
		rename packages packages32-pae dist/packages
	fi
	car=3
	bldkern
	if [[ -z "$DEB" ]]; then
		mkkernsrc
		rename packages packages32-nopae dist/packages
	fi
	;;
	
	123|321|213|312|132|231) car=1
	bldkern
	if [[ -z "$DEB" ]]; then 
		mkkernsrc
		rename packages packages64 dist/packages
	fi
	car=2
	bldkern
	if [[ -z "$DEB" ]]; then 
		mkkernsrc
		rename packages packages32-pae dist/packages
	fi
	car=3
	bldkern
	if [[ -z "$DEB" ]]; then
		mkkernsrc
		rename packages packages32-nopae dist/packages
	fi
	;;
	
	888)	bldkern
	car=1
	if [[ -z "$DEB" ]]; then 
		mkkernsrc
		rename packages packages64 dist/packages
		unset arc
	fi
	car=2
	bldkern
	if [[ -z "$DEB" ]]; then 
		mkkernsrc
		rename packages packages32-pae dist/packages
	fi
	car=3
	bldkern
	if [[ -z "$DEB" ]]; then
		mkkernsrc
		rename packages packages32-nopae dist/packages
	fi
	;;
		
	7) cd dist/sources
	./buildfromsrc
	;;
	*) exit 1
	;;
esac
cd "$CWD"
mv -f /tmp/firmware*.tar.bz2 vanilla/ > build.log 2>&1
rm -f DOTconfig
echo "Compilation has finished." 
if [[ ! -z "$DEB" ]]; then
	rox $PWD/dist/debs &
else
	rox $PWD/dist/packages &
fi
###the end###

